@@ -1,6 +1,6 @@
-/*
-   GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2004, 2006, 2007, 2009 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 2004, 2006-2007, 2009-2012, 2014-2017 Free Software
+   Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -13,10 +13,8 @@
    Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General
-   Public License along with this library; if not, write to the
-   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA
-*/
+   Public License along with this library.  If not, see 
+   <http://www.gnu.org/licenses/>. */
 
 #ifndef _MUCPP_MAILBOX_H
 #define _MUCPP_MAILBOX_H
@@ -24,7 +22,6 @@
 #include <errno.h>
 #include <mailutils/mailbox.h>
 #include <mailutils/cpp/error.h>
-#include <mailutils/cpp/debug.h>
 #include <mailutils/cpp/folder.h>
 #include <mailutils/cpp/message.h>
 #include <mailutils/cpp/url.h>
@@ -56,7 +53,6 @@ class MailboxBase
   void unlock ();
   mu_off_t get_size ();
 
-  Debug& get_debug ();
   Folder& get_folder ();
   Url& get_url ();
 
